import { useState } from "react";
import { Header } from "../../Layout/Card/Header";
import { Input } from "../../Form/form/Input";
import { Button } from "../../Form/Button/Button";
import styles from "./Login.module.css";
import Home from "../../../Assets/Login.png";
import { FaPhoneAlt } from "react-icons/fa";
import PropTypes from "prop-types";
import ReactMarkdown from "react-markdown";
import remarkGfm from "remark-gfm";

export const Login = ({ title, onSubmit = () => {}, markdown, labels }) => {
  const [value, setValue] = useState("");
  const [islesser, setIsLesser] = useState(false);

  const InputChange = (e) => {
    const updated = e.target.value;
    console.log("executed");
    if (/^\d{0,10}$/.test(updated)) {
      setValue(updated);
    }
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    if (value.length < 10) {
      setIsLesser(true);
      return;
    }
    onSubmit({ mobile: value });
    setIsLesser(false);
    setValue("");
  };

  const handleKey = (e) => {
    if (e.key === "Enter") {
      handleSubmit(e);
    }
  };

  return (
    <>
      <div className={`${styles.login} ${styles.round}`}>
        <Header title={title} className={styles.head} />
        <img src={Home} className={styles.img} alt="Login illustration" />

        <div className={styles.form}>
          <form onSubmit={handleSubmit}>
            <div className={styles.inp}>
              <Input
                placeholder={labels.mobilePlaceholder}
                value={value}
                onChange={InputChange}
                type="tel"
                pattern="[6-9][0-9]{9}"
                min="0"
                icon={FaPhoneAlt}
                required
                onKeyDown={handleKey}
              />
            </div>

            {islesser && (
              <span className={styles.span}>{labels.mobileError}</span>
            )}

            <div className={styles.btn}>
              <Button type="submit">{labels.submitBtnText}</Button>
            </div>
          </form>
          <div className={styles.footer}>
            <ReactMarkdown remarkPlugins={[remarkGfm]}>
              {markdown}
            </ReactMarkdown>
          </div>
        </div>
      </div>
    </>
  );
};

Login.propTypes = {
  onSubmit: PropTypes.func,
  onSwitch: PropTypes.func,
  markdown: PropTypes.string,
  labels: PropTypes.shape({
    submitBtnText: PropTypes.string,
    mobilePlaceholder: PropTypes.string,
    mobileInvalid: PropTypes.string,
    mobileError: PropTypes.string,
    mobileRequired: PropTypes.string,
    title: PropTypes.string,
    signUp: PropTypes.string,
    accountLabel: PropTypes.string,
  }),
};
