import { useEffect, useState } from "react";
import { useAppContext } from "../context/Index";
import { Login } from "../components/Forms/Login/Login";
import { Sign } from "../components/Forms/SignUp/Sign";
import styles from "./Styles.module.css";
import { useLocation, useNavigate } from "react-router-dom";
import { toast, ToastContainer } from "react-toastify";

export const LoginPage = () => {
  const navigate = useNavigate();
  const location = useLocation();
  const { loginUser, registerUser } = useAppContext();
  const [showLogin, setShowLogin] = useState(true);

  useEffect(() => {
    sessionStorage.clear();
    if (location.pathname === "/signup") {
      setShowLogin(false);
    }
  }, [location.pathname]);

  const handlelogin = async ({ mobile }) => {
    if (!mobile) {
      toast.error("please Enter Your Number");
      return;
    }
    if (mobile.length < 10) {
      toast.error("Mobile number is less than 10");
      return;
    }
    if (!/^[6-9]\d{9}$/.test(mobile)) {
      toast.info("Invalid Number");
      return;
    }

    const res = await loginUser({ mobile });
    if (res) {
      navigate("/seat-limit");
    }
  };

  const handleSignup = async ({ name, mobile }) => {
    if (!name || !mobile) {
      toast.error("Please enter both name and number");
      return;
    }
    if (!/^[6-9]\d{9}$/.test(mobile)) {
      toast.info("Please enter a valid 10-digit number");
      return;
    }
    const confirmSeat = window.confirm("Are you sure,you want to signUp?");
    if (!confirmSeat) return;
    const res = await registerUser({ name, mobile });
    console.log("registered", res);
    setShowLogin(true);
  };

  return (
    <>
      <div className={styles.login}>
        {showLogin ? (
          <Login
            onSubmit={handlelogin}
            onSwitch={() => setShowLogin(false)}
            markdown={`Don't have an account? [SignUp](/signup)`}
            labels={{
              mobilePlaceholder: "Enter Your Number",
              submitBtnText: "Submit",
              mobileError: "Enter 10 digits",
            }}
          />
        ) : (
          <Sign
            onSubmit={handleSignup}
            onSwitch={() => setShowLogin(true)}
            labels={{
              mobileplaceholder: "Enter Your Number",
              nameplaceholder: "Enter Your Name",
              btnLabel: "Submit",
              titleLabel: "SignUp",
            }}
          />
        )}
      </div>
      <ToastContainer />
    </>
  );
};
